diff --git a/_agent-linux/EHCP/config.php b/_agent-linux/EHCP/config.php
index b4519a21..b1c5a371 100644
--- a/_agent-linux/EHCP/config.php
+++ b/_agent-linux/EHCP/config.php
@@ -37,7 +37,7 @@ function addToLog($errors) {
$createLog = fopen($logFile, 'a+');
if (!$createLog) {
- trigger_error("Unable to create EHCP FTP Integration log file! Please create a file named \"ehcp_ftp_log.txt\" in the ogp_agent install directory under the EHCP folder with permissions of 777", E_USER_NOTICE);
+ trigger_error("Unable to create EHCP FTP Integration log file! Please create a file named \"ehcp_ftp_log.txt\" in the gsp_agent install directory under the EHCP folder with permissions of 777", E_USER_NOTICE);
}
fclose($createLog);
}
diff --git a/_agent-linux/ogp_agent_run b/_agent-linux/gsp_agent_run
similarity index 99%
rename from _agent-linux/ogp_agent_run
rename to _agent-linux/gsp_agent_run
index 371e3296..577fb3a4 100644
--- a/_agent-linux/ogp_agent_run
+++ b/_agent-linux/gsp_agent_run
@@ -121,7 +121,7 @@ detectSystemD(){
echo -e "Updating OGP agent systemd service init script."
echo -e "Copying ogp_agent systemd service file to $SystemDDir"
echo "$sudoPass" | sudo -S -p "" cp "${AGENTDIR}/systemd/ogp_agent.service" "$SystemDDir"
- echo "$sudoPass" | sudo -S -p "" sed -i "s#{OGP_AGENT_PATH}#$AGENTDIR#g" "${SystemDDir}/ogp_agent.service"
+ echo "$sudoPass" | sudo -S -p "" sed -i "s#{GSP_AGENT_PATH}#$AGENTDIR#g" "${SystemDDir}/ogp_agent.service"
echo "$sudoPass" | sudo -S -p "" systemctl daemon-reload
echo "$sudoPass" | sudo -S -p "" systemctl enable ogp_agent.service
echo "$sudoPass" | sudo -S -p "" service ogp_agent restart
diff --git a/_agent-linux/ogp_screenrc b/_agent-linux/gsp_screenrc
similarity index 100%
rename from _agent-linux/ogp_screenrc
rename to _agent-linux/gsp_screenrc
diff --git a/_agent-linux/ogp_screenrc_bk b/_agent-linux/gsp_screenrc_bk
similarity index 100%
rename from _agent-linux/ogp_screenrc_bk
rename to _agent-linux/gsp_screenrc_bk
diff --git a/_agent-linux/includes/ogp_agent.init b/_agent-linux/includes/gsp_agent.init
similarity index 96%
rename from _agent-linux/includes/ogp_agent.init
rename to _agent-linux/includes/gsp_agent.init
index 30d16318..b4d30f45 100644
--- a/_agent-linux/includes/ogp_agent.init
+++ b/_agent-linux/includes/gsp_agent.init
@@ -2,7 +2,7 @@
# Generic Init script if we can't find what kind of Linux we're on
-agent_dir=OGP_AGENT_DIR
+agent_dir=GSP_AGENT_DIR
agent_user=OGP_USER
# Start function.
diff --git a/_agent-linux/includes/ogp_agent.init.dbn b/_agent-linux/includes/gsp_agent.init.dbn
similarity index 99%
rename from _agent-linux/includes/ogp_agent.init.dbn
rename to _agent-linux/includes/gsp_agent.init.dbn
index 2b165be3..fb0c1b3d 100644
--- a/_agent-linux/includes/ogp_agent.init.dbn
+++ b/_agent-linux/includes/gsp_agent.init.dbn
@@ -13,7 +13,7 @@
### END INIT INFO
#
-agent_dir=OGP_AGENT_DIR
+agent_dir=GSP_AGENT_DIR
agent_user=OGP_USER
#
diff --git a/_agent-linux/includes/ogp_agent.init.gentoo b/_agent-linux/includes/gsp_agent.init.gentoo
similarity index 96%
rename from _agent-linux/includes/ogp_agent.init.gentoo
rename to _agent-linux/includes/gsp_agent.init.gentoo
index db3e686f..bc66b3ae 100644
--- a/_agent-linux/includes/ogp_agent.init.gentoo
+++ b/_agent-linux/includes/gsp_agent.init.gentoo
@@ -4,7 +4,7 @@
# GF: Config is in $agent_dir/Cfg/Config.pm
-agent_dir=OGP_AGENT_DIR
+agent_dir=GSP_AGENT_DIR
agent_user=OGP_USER
depend() {
diff --git a/_agent-linux/includes/ogp_agent.init.rh b/_agent-linux/includes/gsp_agent.init.rh
similarity index 99%
rename from _agent-linux/includes/ogp_agent.init.rh
rename to _agent-linux/includes/gsp_agent.init.rh
index b72a7b98..0388af30 100644
--- a/_agent-linux/includes/ogp_agent.init.rh
+++ b/_agent-linux/includes/gsp_agent.init.rh
@@ -8,7 +8,7 @@
# chkconfig: 2345 88 10
# description: Startup/shutdown script for the Game Server Agent
-agent_dir=OGP_AGENT_DIR
+agent_dir=GSP_AGENT_DIR
agent_user=OGP_USER
service=agent
diff --git a/_agent-linux/systemd/ogp_agent.service b/_agent-linux/systemd/gsp_agent.service
similarity index 58%
rename from _agent-linux/systemd/ogp_agent.service
rename to _agent-linux/systemd/gsp_agent.service
index 949ea11d..be136b7a 100644
--- a/_agent-linux/systemd/ogp_agent.service
+++ b/_agent-linux/systemd/gsp_agent.service
@@ -6,10 +6,10 @@ After=network.target
[Service]
Type=oneshot
-ExecStart=/bin/sh -c "{OGP_AGENT_PATH}/agent_init start"
-ExecStop=/bin/sh -c "{OGP_AGENT_PATH}/agent_init stop"
+ExecStart=/bin/sh -c "{GSP_AGENT_PATH}/agent_init start"
+ExecStop=/bin/sh -c "{GSP_AGENT_PATH}/agent_init stop"
RemainAfterExit=yes
-PIDFile="{OGP_AGENT_PATH}/agent_run.pid"
+PIDFile="{GSP_AGENT_PATH}/agent_run.pid"
[Install]
WantedBy=multi-user.target
diff --git a/_agent-windows/EHCP/config.php b/_agent-windows/EHCP/config.php
index b4519a21..b1c5a371 100644
--- a/_agent-windows/EHCP/config.php
+++ b/_agent-windows/EHCP/config.php
@@ -37,7 +37,7 @@ function addToLog($errors) {
$createLog = fopen($logFile, 'a+');
if (!$createLog) {
- trigger_error("Unable to create EHCP FTP Integration log file! Please create a file named \"ehcp_ftp_log.txt\" in the ogp_agent install directory under the EHCP folder with permissions of 777", E_USER_NOTICE);
+ trigger_error("Unable to create EHCP FTP Integration log file! Please create a file named \"ehcp_ftp_log.txt\" in the gsp_agent install directory under the EHCP folder with permissions of 777", E_USER_NOTICE);
}
fclose($createLog);
}
diff --git a/_agent-windows/WorkshopModsInfo/1128256978.ogpmod b/_agent-windows/WorkshopModsInfo/1128256978.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/1128256978.ogpmod
rename to _agent-windows/WorkshopModsInfo/1128256978.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/1334412770.ogpmod b/_agent-windows/WorkshopModsInfo/1334412770.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/1334412770.ogpmod
rename to _agent-windows/WorkshopModsInfo/1334412770.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/1361461340.ogpmod b/_agent-windows/WorkshopModsInfo/1361461340.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/1361461340.ogpmod
rename to _agent-windows/WorkshopModsInfo/1361461340.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/1487484880.ogpmod b/_agent-windows/WorkshopModsInfo/1487484880.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/1487484880.ogpmod
rename to _agent-windows/WorkshopModsInfo/1487484880.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/1559212036.ogpmod b/_agent-windows/WorkshopModsInfo/1559212036.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/1559212036.ogpmod
rename to _agent-windows/WorkshopModsInfo/1559212036.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/1564026768.ogpmod b/_agent-windows/WorkshopModsInfo/1564026768.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/1564026768.ogpmod
rename to _agent-windows/WorkshopModsInfo/1564026768.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/1828439124.ogpmod b/_agent-windows/WorkshopModsInfo/1828439124.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/1828439124.ogpmod
rename to _agent-windows/WorkshopModsInfo/1828439124.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/2116157322.ogpmod b/_agent-windows/WorkshopModsInfo/2116157322.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/2116157322.ogpmod
rename to _agent-windows/WorkshopModsInfo/2116157322.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/2545327648.ogpmod b/_agent-windows/WorkshopModsInfo/2545327648.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/2545327648.ogpmod
rename to _agent-windows/WorkshopModsInfo/2545327648.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/2572331007.ogpmod b/_agent-windows/WorkshopModsInfo/2572331007.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/2572331007.ogpmod
rename to _agent-windows/WorkshopModsInfo/2572331007.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/2791403093.ogpmod b/_agent-windows/WorkshopModsInfo/2791403093.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/2791403093.ogpmod
rename to _agent-windows/WorkshopModsInfo/2791403093.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/2966495799.ogpmod b/_agent-windows/WorkshopModsInfo/2966495799.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/2966495799.ogpmod
rename to _agent-windows/WorkshopModsInfo/2966495799.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/3371742728.ogpmod b/_agent-windows/WorkshopModsInfo/3371742728.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/3371742728.ogpmod
rename to _agent-windows/WorkshopModsInfo/3371742728.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/3483534745.ogpmod b/_agent-windows/WorkshopModsInfo/3483534745.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/3483534745.ogpmod
rename to _agent-windows/WorkshopModsInfo/3483534745.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/450814997.ogpmod b/_agent-windows/WorkshopModsInfo/450814997.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/450814997.ogpmod
rename to _agent-windows/WorkshopModsInfo/450814997.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/485417177.ogpmod b/_agent-windows/WorkshopModsInfo/485417177.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/485417177.ogpmod
rename to _agent-windows/WorkshopModsInfo/485417177.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/497660133.ogpmod b/_agent-windows/WorkshopModsInfo/497660133.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/497660133.ogpmod
rename to _agent-windows/WorkshopModsInfo/497660133.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/497661914.ogpmod b/_agent-windows/WorkshopModsInfo/497661914.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/497661914.ogpmod
rename to _agent-windows/WorkshopModsInfo/497661914.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/541888371.ogpmod b/_agent-windows/WorkshopModsInfo/541888371.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/541888371.ogpmod
rename to _agent-windows/WorkshopModsInfo/541888371.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/647753401.ogpmod b/_agent-windows/WorkshopModsInfo/647753401.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/647753401.ogpmod
rename to _agent-windows/WorkshopModsInfo/647753401.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/843425103.ogpmod b/_agent-windows/WorkshopModsInfo/843425103.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/843425103.ogpmod
rename to _agent-windows/WorkshopModsInfo/843425103.gspmod
diff --git a/_agent-windows/WorkshopModsInfo/861133494.ogpmod b/_agent-windows/WorkshopModsInfo/861133494.gspmod
similarity index 100%
rename from _agent-windows/WorkshopModsInfo/861133494.ogpmod
rename to _agent-windows/WorkshopModsInfo/861133494.gspmod
diff --git a/_agent-windows/ogp_agent.pl b/_agent-windows/gsp_agent.pl
similarity index 99%
rename from _agent-windows/ogp_agent.pl
rename to _agent-windows/gsp_agent.pl
index 389fff4b..a725912c 100644
--- a/_agent-windows/ogp_agent.pl
+++ b/_agent-windows/gsp_agent.pl
@@ -62,7 +62,7 @@ use constant AGENT_VERSION => $Cfg::Config{version};
use constant SCREEN_LOG_LOCAL => $Cfg::Preferences{screen_log_local};
use constant DELETE_LOGS_AFTER => $Cfg::Preferences{delete_logs_after};
use constant AGENT_PID_FILE =>
- Path::Class::File->new(AGENT_RUN_DIR, 'ogp_agent.pid');
+ Path::Class::File->new(AGENT_RUN_DIR, 'gsp_agent.pid');
use constant AGENT_RSYNC_GENERIC_LOG =>
Path::Class::File->new(AGENT_RUN_DIR, 'rsync_update_generic.log');
use constant STEAM_LICENSE_OK => "Accept";
@@ -3367,9 +3367,9 @@ sub agent_restart
if ($dec_check eq 'restart')
{
chdir AGENT_RUN_DIR;
- if(-e "ogp_agent_run.pid")
+ if(-e "gsp_agent_run.pid")
{
- my $init_pid = `cat ogp_agent_run.pid`;
+ my $init_pid = `cat gsp_agent_run.pid`;
chomp($init_pid);
if(kill 0, $init_pid)
@@ -3378,7 +3378,7 @@ sub agent_restart
my $rm_pid_file = "";
my $agent_pid = "";
my $restart_scr_log = Path::Class::File->new(SCREEN_LOGS_DIR, 'screenlog.agent_restart');
- my $agent_scr_log = Path::Class::File->new(SCREEN_LOGS_DIR, 'screenlog.ogp_agent');
+ my $agent_scr_log = Path::Class::File->new(SCREEN_LOGS_DIR, 'screenlog.gsp_agent');
if(-e $restart_scr_log)
{
@@ -3390,10 +3390,10 @@ sub agent_restart
unlink $agent_scr_log;
}
- if(-e "ogp_agent.pid")
+ if(-e "gsp_agent.pid")
{
- $rm_pid_file .= " ogp_agent.pid";
- $agent_pid = `cat ogp_agent.pid`;
+ $rm_pid_file .= " gsp_agent.pid";
+ $agent_pid = `cat gsp_agent.pid`;
chomp($agent_pid);
if( kill 0, $agent_pid )
{
@@ -3419,8 +3419,8 @@ sub agent_restart
"while [ -e /proc/$init_pid $or_exist ];do echo -n .;sleep 1;done\n".
"rm -f $rm_pid_file\necho \" [OK]\"\n".
"echo -n \"Starting OGP Agent...\"\n".
- "screen -d -m -t \"ogp_agent\" -c \"" . SCREENRC_FILE . "\" -S ogp_agent bash ogp_agent -pidfile /OGP/ogp_agent_run.pid\n".
- "while [ ! -e 'ogp_agent.pid' ];do echo -n .;sleep 1;done\n".
+ "screen -d -m -t \"gsp_agent\" -c \"" . SCREENRC_FILE . "\" -S gsp_agent bash gsp_agent -pidfile /OGP/gsp_agent_run.pid\n".
+ "while [ ! -e 'gsp_agent.pid' ];do echo -n .;sleep 1;done\n".
"echo \" [OK]\"\n".
"rm -f tmp_restart.sh\n".
"exit 0\n";
@@ -4219,7 +4219,7 @@ sub generate_post_install_scripts
' fi'."\n".
' fi'."\n".
' if [ ! -d "${mods_info_path}" ];then mkdir -p "${mods_info_path}";fi'."\n".
- ' echo "${mod_name[$i]}" > "${mods_info_path}${mod_string[$i]}.ogpmod"'."\n".
+ ' echo "${mod_name[$i]}" > "${mods_info_path}${mod_string[$i]}.gspmod"'."\n".
' i=$(expr $i + 1)'."\n".
'done'."\n";
return "$post_install_scripts";
@@ -4237,7 +4237,7 @@ sub get_workshop_mods_info()
my @mods_info;
while(my $mod_info_file = readdir(MODS_INFO_DIR))
{
- if($mod_info_file =~ /\.ogpmod$/)
+ if($mod_info_file =~ /\.gspmod$/)
{
my $mod_info_file_path = Path::Class::File->new($mods_info_dir_path, $mod_info_file);
if(open(my $fh, '<:encoding(UTF-8)', $mod_info_file_path))
diff --git a/_agent-windows/ogp_screenrc b/_agent-windows/gsp_screenrc
similarity index 100%
rename from _agent-windows/ogp_screenrc
rename to _agent-windows/gsp_screenrc
diff --git a/_agent-windows/ogp_screenrc_bk b/_agent-windows/gsp_screenrc_bk
similarity index 100%
rename from _agent-windows/ogp_screenrc_bk
rename to _agent-windows/gsp_screenrc_bk
diff --git a/ogp_api.php b/gsp_api.php
similarity index 96%
rename from ogp_api.php
rename to gsp_api.php
index bec56a1c..c398cbc5 100644
--- a/ogp_api.php
+++ b/gsp_api.php
@@ -1,59 +1,59 @@
';
diff --git a/js/modules/gamemanager.js b/js/modules/gamemanager.js
index fd37058e..8dc1e56b 100644
--- a/js/modules/gamemanager.js
+++ b/js/modules/gamemanager.js
@@ -214,7 +214,7 @@ function saveGameServerOrder(){
// Make the call
$.ajax({
type: "POST",
- url: "ogp_api.php?gamemanager_admin/reorder&token=" + userAPIKey,
+ url: "gsp_api.php?gamemanager_admin/reorder&token=" + userAPIKey,
data: JSON.stringify(postData),
success: function(e){
logToConsole("Game server order successfully saved!");
diff --git a/modules/cron/cron.php b/modules/cron/cron.php
index 2ebdc1e2..4f177949 100644
--- a/modules/cron/cron.php
+++ b/modules/cron/cron.php
@@ -60,16 +60,16 @@ function exec_ogp_module()
switch ($_POST['action']) {
case "stop":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/stop&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/stop&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
break;
case "start":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/start&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/start&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
break;
case "restart":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/restart&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/restart&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
break;
case "steam_auto_update":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/update&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}&type=steam\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/update&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}&type=steam\" --no-check-certificate > /dev/null 2>&1";
break;
}
diff --git a/modules/cron/shared_cron_functions.php b/modules/cron/shared_cron_functions.php
index f9c1691b..9b9f6be1 100644
--- a/modules/cron/shared_cron_functions.php
+++ b/modules/cron/shared_cron_functions.php
@@ -231,16 +231,16 @@ function updateCronJobsToNewApi()
switch ($action) {
case "stopServer":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/stop&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/stop&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
break;
case "startServer":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/start&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/start&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
break;
case "restartServer":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/restart&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/restart&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
break;
case "autoUpdateSteamHome":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/update&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}&type=steam\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/update&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}&type=steam\" --no-check-certificate > /dev/null 2>&1";
break;
}
list($minute,$hour,$dayOfTheMonth,$month,$dayOfTheWeek,$old_command) = explode(" ", $job, 6);
diff --git a/modules/cron/user_cron.php b/modules/cron/user_cron.php
index 148c3a42..107ede88 100644
--- a/modules/cron/user_cron.php
+++ b/modules/cron/user_cron.php
@@ -61,16 +61,16 @@ function exec_ogp_module()
switch ($_POST['action']) {
case "stop":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/stop&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/stop&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
break;
case "start":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/start&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/start&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
break;
case "restart":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/restart&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/restart&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}\" --no-check-certificate > /dev/null 2>&1";
break;
case "steam_auto_update":
- $command = "wget -qO- \"${panelURL}/ogp_api.php?gamemanager/update&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}&type=steam\" --no-check-certificate > /dev/null 2>&1";
+ $command = "wget -qO- \"${panelURL}/gsp_api.php?gamemanager/update&token=${token}&ip=${ip}&port=${port}&mod_key=${mod_key}&type=steam\" --no-check-certificate > /dev/null 2>&1";
break;
}
diff --git a/modules/faq/ogpfaq.rss b/modules/faq/gspfaq.rss
similarity index 100%
rename from modules/faq/ogpfaq.rss
rename to modules/faq/gspfaq.rss
diff --git a/modules/gamemanager/mini_start.php b/modules/gamemanager/mini_start.php
index 8c0ca828..2c5a84f1 100644
--- a/modules/gamemanager/mini_start.php
+++ b/modules/gamemanager/mini_start.php
@@ -85,7 +85,7 @@ if( !isset( $_POST['start_server'] ) )
\n
\n
- | ". get_lang("ogp_agent_ip") .
+ |
| ". get_lang("gsp_agent_ip") .
": | ".$server_home['agent_ip']." |
";
$max_players = $server_home['max_players'];
@@ -565,7 +565,7 @@ elseif($server_home['home_id'] == $_POST['home_id'])
$db->changeLastParam($server_home['home_id'],json_encode($save_param));
echo "";
- echo "| ". get_lang("ogp_agent_ip") .
+ echo " |
| ". get_lang("gsp_agent_ip") .
": | ".$server_home['agent_ip']." |
\n";
echo "| ". get_lang("game_home") .
": | ".$server_home['home_path']." |
";
diff --git a/modules/server/restart.php b/modules/server/restart.php
index 7612febf..9a1e2e9c 100644
--- a/modules/server/restart.php
+++ b/modules/server/restart.php
@@ -28,7 +28,7 @@ function exec_ogp_module() {
{
$remote->remote_readfile( "screenlogs/screenlog.agent_restart", $restart_log );
echo "".$restart_log."
";
- $remote->remote_readfile( "screenlogs/screenlog.ogp_agent", $agent_log );
+ $remote->remote_readfile( "screenlogs/screenlog.gsp_agent", $agent_log );
if($agent_log == "")
{
$view->refresh("?m=server&p=restart&rhost_id=".$rhost_id."&refresh",5);
@@ -54,7 +54,7 @@ function exec_ogp_module() {
} else if($_POST['re_check'] == "yes") {
// Confirmed... so restart the agent
$remote->exec( "if [ -e 'screenlogs/screenlog.agent_restart' ]; then rm -f 'screenlogs/screenlog.agent_restart'; fi && ".
- "if [ -e 'screenlogs/screenlog.ogp_agent' ]; then rm -f 'screenlogs/screenlog.ogp_agent'; fi" );
+ "if [ -e 'screenlogs/screenlog.gsp_agent' ]; then rm -f 'screenlogs/screenlog.gsp_agent'; fi" );
$file_info = $remote->agent_restart();
// 5 seconds should be enough for the agent to come back up
echo get_lang("restarting"); # "Restarting agent... Please wait."
diff --git a/modules/server/view_log.php b/modules/server/view_log.php
index 58e27a70..454b1431 100644
--- a/modules/server/view_log.php
+++ b/modules/server/view_log.php
@@ -14,7 +14,7 @@ function exec_ogp_module() {
$remote = new OGPRemoteLibrary($remote_server['agent_ip'], $remote_server['agent_port'], $remote_server['encryption_key'], $remote_server['timeout'] );
if(isset($_POST['save_file']))
{
- $file_info = $remote->remote_writefile('./ogp_agent.log', strip_real_escape_string($_REQUEST['file_content']));
+ $file_info = $remote->remote_writefile('./gsp_agent.log', strip_real_escape_string($_REQUEST['file_content']));
if ( $file_info === 1 )
{
print_success( get_lang("wrote_changes") );
@@ -27,7 +27,7 @@ function exec_ogp_module() {
}
}
$data = "";
- $file_info = $remote->remote_readfile('./ogp_agent.log',$data);
+ $file_info = $remote->remote_readfile('./gsp_agent.log',$data);
if ( $file_info === 0 )
{
print_failure( get_lang("not_found") );
diff --git a/themes/AdminLTE/dist/img/ogp_logo_dark.svg b/themes/AdminLTE/dist/img/gsp_logo_dark.svg
similarity index 100%
rename from themes/AdminLTE/dist/img/ogp_logo_dark.svg
rename to themes/AdminLTE/dist/img/gsp_logo_dark.svg
diff --git a/themes/AdminLTE/dist/img/ogp_logo_light.svg b/themes/AdminLTE/dist/img/gsp_logo_light.svg
similarity index 100%
rename from themes/AdminLTE/dist/img/ogp_logo_light.svg
rename to themes/AdminLTE/dist/img/gsp_logo_light.svg
diff --git a/themes/AdminLTE/dist/js/main.js b/themes/AdminLTE/dist/js/main.js
index 99dcbcba..312bd386 100644
--- a/themes/AdminLTE/dist/js/main.js
+++ b/themes/AdminLTE/dist/js/main.js
@@ -411,7 +411,7 @@ $(document).ready(function()
var boxClass = 'login-box';
var headerContent = '\
\
-
\
+
\
';
if(new_form !== undefined)
@@ -1287,7 +1287,7 @@ function themeChanger(changeTo, save = false)
if(!localStorage.getItem('themeLogo'))
{
- $('img.brand-image').attr('src', 'themes/AdminLTE/dist/img/ogp_logo_dark.svg');
+ $('img.brand-image').attr('src', 'themes/AdminLTE/dist/img/gsp_logo_dark.svg');
}
$('link[href*="jquery-ui.min"]').attr('href', 'themes/AdminLTE/plugins/jquery-ui/jquery-ui.min.dark.css');
@@ -1318,7 +1318,7 @@ function themeChanger(changeTo, save = false)
if(!localStorage.getItem('themeLogo'))
{
- $('img.brand-image').attr('src', 'themes/AdminLTE/dist/img/ogp_logo_light.svg');
+ $('img.brand-image').attr('src', 'themes/AdminLTE/dist/img/gsp_logo_light.svg');
}
$('link[href*="jquery-ui.min"]').attr('href', 'themes/AdminLTE/plugins/jquery-ui/jquery-ui.min.light.css');
@@ -1349,7 +1349,7 @@ function themeChanger(changeTo, save = false)
if(!localStorage.getItem('themeLogo'))
{
- $('img.brand-image').attr('src', 'themes/AdminLTE/dist/img/ogp_logo_dark.svg');
+ $('img.brand-image').attr('src', 'themes/AdminLTE/dist/img/gsp_logo_dark.svg');
}
$('link[href*="jquery-ui.min"]').attr('href', 'themes/AdminLTE/plugins/jquery-ui/jquery-ui.min.light.css');
diff --git a/themes/AdminLTE/layout.html b/themes/AdminLTE/layout.html
index 77caa37d..ac7e03a1 100644
--- a/themes/AdminLTE/layout.html
+++ b/themes/AdminLTE/layout.html
@@ -74,7 +74,7 @@
diff --git a/_agent-linux/ogp_agent.log b/_agent-linux/gsp_agent.log
similarity index 100%
rename from _agent-linux/ogp_agent.log
rename to _agent-linux/gsp_agent.log
diff --git a/_agent-linux/ogp_agent.log.bak b/_agent-linux/gsp_agent.log.bak
similarity index 100%
rename from _agent-linux/ogp_agent.log.bak
rename to _agent-linux/gsp_agent.log.bak
diff --git a/_agent-linux/ogp_agent.pid b/_agent-linux/gsp_agent.pid
similarity index 100%
rename from _agent-linux/ogp_agent.pid
rename to _agent-linux/gsp_agent.pid
diff --git a/_agent-linux/ogp_agent.pl b/_agent-linux/gsp_agent.pl
similarity index 99%
rename from _agent-linux/ogp_agent.pl
rename to _agent-linux/gsp_agent.pl
index 51971737..d2a6d961 100644
--- a/_agent-linux/ogp_agent.pl
+++ b/_agent-linux/gsp_agent.pl
@@ -66,7 +66,7 @@ use constant SCREEN_LOG_LOCAL => $Cfg::Preferences{screen_log_local};
use constant DELETE_LOGS_AFTER => $Cfg::Preferences{delete_logs_after};
use constant LINUX_USER_PER_GAME_SERVER => $Cfg::Preferences{linux_user_per_game_server};
use constant AGENT_PID_FILE =>
- Path::Class::File->new(AGENT_RUN_DIR, 'ogp_agent.pid');
+ Path::Class::File->new(AGENT_RUN_DIR, 'gsp_agent.pid');
use constant AGENT_RSYNC_GENERIC_LOG =>
Path::Class::File->new(AGENT_RUN_DIR, 'rsync_update_generic.log');
use constant STEAM_LICENSE_OK => "Accept";
@@ -864,7 +864,7 @@ sub universal_start_without_decrypt
}
}
# Fix perms on ogp_agent user's homedir so that other users can access their owned files within this dir
my $fixOGPHomeDirCommand = 'chmod -R ug+rwx $( getent passwd "' . $ogpAgentGroup . '" | cut -d: -f6 )';
sudo_exec_without_decrypt($fixOGPHomeDirCommand);
@@ -3800,19 +3800,19 @@ sub agent_restart
if ($dec_check eq 'restart')
{
chdir AGENT_RUN_DIR;
- if(-e "ogp_agent_run.pid")
+ if(-e "gsp_agent_run.pid")
{
- my $init_pid = `cat ogp_agent_run.pid`;
+ my $init_pid = `cat gsp_agent_run.pid`;
chomp($init_pid);
if(kill 0, $init_pid)
{
my $or_exist = "";
my $rm_pid_file = "";
- if(-e "ogp_agent.pid")
+ if(-e "gsp_agent.pid")
{
- $rm_pid_file = " ogp_agent.pid";
- my $agent_pid = `cat ogp_agent.pid`;
+ $rm_pid_file = " gsp_agent.pid";
+ my $agent_pid = `cat gsp_agent.pid`;
chomp($agent_pid);
if( kill 0, $agent_pid )
{
@@ -3824,10 +3824,10 @@ sub agent_restart
my $restart = "echo -n \"Stopping OGP Agent...\"\n".
"kill $init_pid\n".
"while [ -e /proc/$init_pid $or_exist ];do echo -n .;sleep 1;done\n".
- "rm -f ogp_agent_run.pid $rm_pid_file\necho \" [OK]\"\n".
+ "rm -f gsp_agent_run.pid $rm_pid_file\necho \" [OK]\"\n".
"echo -n \"Starting OGP Agent...\"\n".
- "screen -d -m -t \"ogp_agent\" -c \"" . SCREENRC_FILE . "\" -S ogp_agent bash ogp_agent_run -pidfile ogp_agent_run.pid\n".
- "while [ ! -e ogp_agent_run.pid -o ! -e ogp_agent.pid ];do echo -n .;sleep 1;done\n".
+ "screen -d -m -t \"gsp_agent\" -c \"" . SCREENRC_FILE . "\" -S gsp_agent bash gsp_agent_run -pidfile gsp_agent_run.pid\n".
+ "while [ ! -e gsp_agent_run.pid -o ! -e gsp_agent.pid ];do echo -n .;sleep 1;done\n".
"echo \" [OK]\"\n".
"rm -f tmp_restart.sh\n".
"exit 0\n";
@@ -4648,7 +4648,7 @@ sub generate_post_install_scripts
' fi'."\n".
' fi'."\n".
' if [ ! -d "${mods_info_path}" ];then mkdir -p "${mods_info_path}";fi'."\n".
- ' echo "${mod_name[$i]}" > "${mods_info_path}${mod_string[$i]}.ogpmod"'."\n".
+ ' echo "${mod_name[$i]}" > "${mods_info_path}${mod_string[$i]}.gspmod"'."\n".
' i=$(expr $i + 1)'."\n".
'done'."\n";
return "$post_install_scripts";
@@ -4666,7 +4666,7 @@ sub get_workshop_mods_info()
my @mods_info;
while(my $mod_info_file = readdir(MODS_INFO_DIR))
{
- if($mod_info_file =~ /\.ogpmod$/)
+ if($mod_info_file =~ /\.gspmod$/)
{
my $mod_info_file_path = Path::Class::File->new($mods_info_dir_path, $mod_info_file);
if(open(my $fh, '<:encoding(UTF-8)', $mod_info_file_path))
@@ -864,7 +864,7 @@ sub universal_start_without_decrypt
}
}
- # Fix perms on ogp_agent user's homedir so that other users can access their owned files within this dir
+ # Fix perms on gsp_agent user's homedir so that other users can access their owned files within this dir
my $fixOGPHomeDirCommand = 'chmod -R ug+rwx $( getent passwd "' . $ogpAgentGroup . '" | cut -d: -f6 )';
sudo_exec_without_decrypt($fixOGPHomeDirCommand);
diff --git a/_agent-linux/install.sh b/_agent-linux/install.sh
index f660eaa0..7f075f9e 100644
--- a/_agent-linux/install.sh
+++ b/_agent-linux/install.sh
@@ -77,7 +77,7 @@ copySystemDInit(){
if [ ! -e "$SystemDDir/ogp_agent.service" ]; then
echo -e "Copying ogp_agent systemd service file to $SystemDDir"
echo "$sudoPass" | sudo -S -p "" cp "${AGENTDIR}/systemd/ogp_agent.service" "$SystemDDir"
- echo "$sudoPass" | sudo -S -p "" sed -i "s#{OGP_AGENT_PATH}#$AGENTDIR#g" "${SystemDDir}/ogp_agent.service"
+ echo "$sudoPass" | sudo -S -p "" sed -i "s#{GSP_AGENT_PATH}#$AGENTDIR#g" "${SystemDDir}/ogp_agent.service"
fi
fi
fi
@@ -292,8 +292,8 @@ fi
init_file=${init_dir}/ogp_agent
cp -f $init_file_template $init_file || failed "Failed to create init file ($init_file)."
-# Next we replace the OGP_AGENT_DIR with the actual dir in init file.
-sed -i "s|OGP_AGENT_DIR|${agent_home}|" ${init_file} || failed "Failed to modify init file ($init_file)."
+# Next we replace the GSP_AGENT_DIR with the actual dir in init file.
+sed -i "s|GSP_AGENT_DIR|${agent_home}|" ${init_file} || failed "Failed to modify init file ($init_file)."
sed -i "s|OGP_USER|${username}|" ${init_file} || failed "Failed to modify init file ($init_file)."
chmod a+x $init_file